# Epydoc Log

Epydoc started at Sat Jan 26 22:29:00 2013

## In /Users/luckow/workspace-saga/bigjob/BigJob/pilot/filemanagement/webhdfs_adaptor.py: Import failed (but source code parsing was successful).

Error: ImportError: No module named webhdfs.webhdfs (line 11)
Warning: Module bliss.saga.Url is shadowed by a variable with the same name.

## In /Users/luckow/workspace-saga/bigjob/BigJob/pilot/coordination/advert_adaptor.py: Import failed (but source code parsing was successful).

Error:

    ImportError: dlopen(/opt/local/saga-1.7/lib/python2.7/site-packages/saga/_engine.so, 2): Library not loaded: libsaga_package_advert.dylib
      Referenced from: /opt/local/saga-1.7/lib/python2.7/site-packages/saga/_engine.so
      Reason: image not found (line 2)

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/api/compute/api.py, line 249, in pilot.api.compute.api.ComputeUnitService.add_pilot_job_service

Docstring Warning: Line 253: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/api/compute/api.py, line 262, in pilot.api.compute.api.ComputeUnitService.remove_pilot_job_service

Docstring Warning: Line 269: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/api/data/api.py, line 233, in pilot.api.data.api.DataUnit.get_state

Docstring Warning: Line 235: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/filemanagement/irods_adaptor.py, line 29, in pilot.filemanagement.irods_adaptor.iRodsFileAdaptor

Docstring Warning: Lines 32, 34: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/filemanagement/s3_adaptor.py, line 40, in pilot.filemanagement.s3_adaptor.S3FileAdaptor

Docstring Warning: Lines 43, 48, 50: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/impl/pilot_manager.py, line 311, in pilot.impl.pilot_manager.ComputeDataService.__expand_working_directory

Docstring Warning: Line 320: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/impl/pilot_manager.py, line 233, in pilot.impl.pilot_manager.ComputeDataService._schedule_du

Docstring Warning: Line 236: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/impl/pilot_manager_decentral.py, line 272, in pilot.impl.pilot_manager_decentral.ComputeDataServiceDecentral._schedule_du

Docstring Warning: Line 275: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/impl/pilot_manager_decentral.py, line 104, in pilot.impl.pilot_manager_decentral.ComputeDataServiceDecentral.remove_pilot_compute_service

Docstring Warning: Line 111: Improper paragraph indentation.

## File /Users/luckow/workspace-saga/bigjob/BigJob/pilot/impl/pilotdata_manager.py, line 526, in pilot.impl.pilotdata_manager.DataUnit.list

Docstring Warning:

    Line 526: Unbalanced '{'.

    ...ems contained in DU {
                           ^

Docstring Warning: Lines 528, 529, 531: Improper paragraph indentation.
Docstring Warning:

    Line 532: Unbalanced '}'.

    }
    ^

## Epydoc Options

configfiles | `=` | `['doc/epydoc.bj.cfg']`
css | `=` | `'./doc/epydoc.css'`
debug | `=` | `True`
dotpath | `=` | `'dot'`
graph_font | `=` | `'Helvetica'`
graph_font_size | `=` | `10`
include_log | `=` | `True`
inheritance | `=` | `'included'`
names | `=` | `['pilot']`
prj_name | `=` | `'BigJob'`
prj_url | `=` | `'http://saga-project.github.com/BigJob'`
show_frames | `=` | `False`
show_private | `=` | `False`
target | `=` | `'./doc/html'`
verbosity | `=` | `1`
action | `=` | `'html'`
docformat | `=` | `'epytext'`
exclude | `=` | `["'[a-zA-Z.]+'"]`
exclude_introspect | `=` | `[]`
exclude_parse | `=` | `[]`
external_api | `=` | `[]`
external_api_file | `=` | `[]`
external_api_root | `=` | `[]`
fail_on | `=` | `None`
graphs | `=` | `['umlclasstree']`
help_file | `=` | `None`
include_source_code | `=` | `True`
introspect | `=` | `True`
list_classes_separately | `=` | `False`
load_pickle | `=` | `False`
parse | `=` | `True`
prj_link | `=` | `None`
profile | `=` | `False`
pstat_files | `=` | `[]`
quiet | `=` | `0`
redundant_details | `=` | `False`
show_imports | `=` | `False`
simple_term | `=` | `False`
src_code_tab_width | `=` | `8`
top_page | `=` | `None`
verbose | `=` | `0`

Epydoc finished at Sat Jan 26 22:29:08 2013

(Elapsed time: 8 seconds)